function gt = makeFilters(numChan, fRange, fs)

if nargin < 1
    fRange = [80, 5000]; % default frequency range in Hz
end
if nargin < 2
    fs = 16000;     % default sampling frequency
end


filterOrder = 4;    % filter order
gL = 2048;          % gammatone filter length or 128 ms for 16 kHz sampling rate

phase(1:numChan) = zeros(numChan,1);        % initial phases
erb_b = hz2erb(fRange);       % upper and lower bound of ERB
erb = [erb_b(1):diff(erb_b)/(numChan-1):erb_b(2)];     % ERB segment
cf = erb2hz(erb);       % center frequency array indexed by channel
b = 1.019*24.7*(4.37*cf/1000+1);       % rate of decay or bandwidth

d = 2^ceil(log2(fs));

% Generating gammatone impulse responses with middle-ear gain normalization
gL = 2048;      % gammatone filter length or 128 ms for 16 kHz sampling rate
gt = zeros(numChan,gL);
tmp_t = [1:gL]/fs;
for c = 1:numChan
    gain = 1/3*(2*pi*b(c)/fs).^4;
    gt(c,:) = gain*fs^3*tmp_t.^(filterOrder-1).*exp(-2*pi*b(c)*tmp_t).*cos(2*pi*cf(c)*tmp_t+phase(c));
end

% find scaling factor to make overall response in pass-band as close to 1
% as possible
x = fft(gt',d);
y = sum(abs(x).^2,2);
fInds = round(cf(11:117)./(fs/d));
y = y(fInds);
z = ones(size(y));

scale = ((y'*z)/(y'*y))^.5;

gt = gt*scale;
